robotpy-ctre
============

This is a python wrapper around the CTRE Phoenix library. The RobotPy project
is not associated with or endorsed by Cross The Road Electronics.

Documentation
=============

* `Installation <http://robotpy.readthedocs.io/en/stable/install/ctre.html>`_
* `Python API Documentation <http://robotpy.readthedocs.io/projects/ctre/en/stable/api.html>`_
* `CTRE's software guide <https://github.com/CrossTheRoadElec/Phoenix-Documentation/blob/master/README.md>`_


Developers Notes
================

Notes for advanced users and developers can be found in develop.md in the git
repository.

License
=======

RobotPy specific bits are available under the Apache 2.0 license. The CTRE
binaries are available under their custom license which basically says "you may
only use this software with our hardware". See LICENSE for details.

Author
======

Dustin Spicuzza (dustin@virtualroadside.com)
